API Documentation
=================

SegMate
-------
.. currentmodule:: segmate.segmate

.. autoclass:: SegMate
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

Object Detector
---------------
.. currentmodule:: segmate.object_detector

.. autoclass:: ObjectDetector
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

.. autoclass:: GroundingDINO
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
      
Dataset
-----------

.. currentmodule:: segmate.dataset

.. autoclass:: BISDataset
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
